==> haskell-tasty-discover-4.2.4-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-discover.sh <==
#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-4.2.4/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-discover
version:              4.2.4
visibility:           public
id:                   tasty-discover-4.2.4-6FEO4ZaFX7YJJu0tb1FKPe
key:                  tasty-discover-4.2.4-6FEO4ZaFX7YJJu0tb1FKPe
license:              MIT
copyright:
    2016 Luke Murphy
    2020-2021 John Ky

maintainer:           John Ky <newhoggy@gmail.com>
author:               Luke Murphy
stability:            Experimental
homepage:             https://github.com/haskell-works/tasty-discover
synopsis:             Test discovery for the tasty framework.
description:
    Automatic test discovery and runner for the tasty framework.
    Prefix your test case names and tasty-discover will discover, collect and run them.
    All popular test libraries are covered. Configure once and then just write your tests.
    Avoid forgetting to add test modules to your Cabal/Hpack files.
    Tasty ingredients are included along with various configuration options for different
    use cases.
    Please see the `README.md` below for how to get started.

category:             Testing
abi:                  9587b308ec9dfc66f87d94fae4866952
exposed:              True
exposed-modules:
    Test.Tasty.Discover Test.Tasty.Discover.Internal.Config
    Test.Tasty.Discover.Internal.Driver
    Test.Tasty.Discover.Internal.Generator
    Test.Tasty.Discover.TastyInfo Test.Tasty.Discover.Version

hidden-modules:       Paths_tasty_discover
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-discover-4.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-discover-4.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-discover
hs-libraries:         HStasty-discover-4.2.4-6FEO4ZaFX7YJJu0tb1FKPe
depends:
    Glob-0.10.2-K3hmTBdRsZw8onVwFa5nKM base-4.15.1.0 containers-0.6.4.1
    directory-1.3.6.2 filepath-1.4.2.1
    tasty-1.4.2.3-LfCoZZg5ttU5VpHV083ruq

haddock-interfaces:
    /usr/share/doc/haskell-tasty-discover/html/tasty-discover.haddock

haddock-html:         /usr/share/doc/haskell-tasty-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-discover-5.0.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-discover.sh <==
#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-5.0.0/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-discover
version:              5.0.0
visibility:           public
id:                   tasty-discover-5.0.0-9uq5xW62NMGCW3lbNXFaOe
key:                  tasty-discover-5.0.0-9uq5xW62NMGCW3lbNXFaOe
license:              MIT
copyright:
    2016 Luke Murphy
    2020-2022 John Ky

maintainer:           John Ky <newhoggy@gmail.com>
author:               Luke Murphy
stability:            Experimental
homepage:             https://github.com/haskell-works/tasty-discover
synopsis:             Test discovery for the tasty framework.
description:
    Automatic test discovery and runner for the tasty framework.
    Prefix your test case names and tasty-discover will discover, collect and run them.
    All popular test libraries are covered. Configure once and then just write your tests.
    Avoid forgetting to add test modules to your Cabal/Hpack files.
    Tasty ingredients are included along with various configuration options for different
    use cases.
    Please see the `README.md` below for how to get started.

category:             Testing
abi:                  0a4d238ebb2aaa4386dc75d8be69b791
exposed:              True
exposed-modules:
    Test.Tasty.Discover Test.Tasty.Discover.Internal.Config
    Test.Tasty.Discover.Internal.Driver
    Test.Tasty.Discover.Internal.Generator
    Test.Tasty.Discover.TastyInfo Test.Tasty.Discover.Version

hidden-modules:       Paths_tasty_discover
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-discover-5.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-discover-5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-discover
hs-libraries:         HStasty-discover-5.0.0-9uq5xW62NMGCW3lbNXFaOe
depends:
    Glob-0.10.2-2hpHTQOFOu786tzr1Hmjwm base-4.15.1.0 containers-0.6.4.1
    directory-1.3.6.2 filepath-1.4.2.1
    tasty-1.4.2.3-5g26BST7AomGP7PDx0otzq

haddock-interfaces:
    /usr/share/doc/haskell-tasty-discover/html/tasty-discover.haddock

haddock-html:         /usr/share/doc/haskell-tasty-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
